==> lifestyle-pimcore-sylius-1.0.1-493bb3.zip: src/Lifestyle/Pimcore/SyliusBundle/Export/Taxon/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update;

use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Handler as TaxonHandler;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update\Model\Taxon;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update\Model\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update
 */
class Mapper
{
    /**
     * @param DataCollectorInterface $collector
     * @return Taxon
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $taxon = new Taxon();
        $taxon->setCode($collector->getItemValue('id'));

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $translation = new Translation();

            $this->mapTranslationField($translation, $collector, 'name', $locale);
            $this->mapTranslationField($translation, $collector, 'description', $locale);
            $this->mapTranslationField($translation, $collector, 'slug', $locale);

            $translation->setLocale($locale);
            $taxon->addTranslation($translation);
        }

        $this->mapParentTaxon($taxon, $collector);

        return $taxon;
    }

    /**
     * @param Translation $translation
     * @param DataCollectorInterface $collector
     * @param string $fieldName
     * @param string $locale
     */
    private function mapTranslationField(Translation $translation, DataCollectorInterface $collector, $fieldName, $locale)
    {
        if ($collector->hasItem($fieldName, $locale)) {
            $method = 'set' . ucfirst(strtolower($fieldName));
            $translation->$method($collector->getItemValue($fieldName, $locale));
        }
    }

    /**
     * @param Taxon $taxon
     * @param DataCollectorInterface $collector
     */
    private function mapParentTaxon(Taxon $taxon, DataCollectorInterface $collector)
    {
        if (
            $collector->getItemValue('parentId') &&
            TaxonHandler::HANDLER_ID === $collector->getItemValue('parentClassName')
        ) {
            $taxon->setParent($collector->getItemValue('parentId'));
        }
    }
}

==> lifestyle-pimcore-sylius-1.0.2-986783.zip: src/Lifestyle/Pimcore/SyliusBundle/Export/Taxon/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update;

use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Handler as TaxonHandler;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update\Model\Request\Taxon;
use Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Pimcore\SyliusBundle\Export\Taxon\Version1\Update
 */
class Mapper
{
    /**
     * @param DataCollectorInterface $collector
     * @return Taxon
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $taxon = new Taxon();
        $taxon->setCode($collector->getItemValue('id'));

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $translation = new Translation();

            $this->mapTranslationField($translation, $collector, 'name', $locale);
            $this->mapTranslationField($translation, $collector, 'description', $locale);
            $this->mapTranslationField($translation, $collector, 'slug', $locale);

            $translation->setLocale($locale);
            $taxon->addTranslation($translation);
        }

        $this->mapParentTaxon($taxon, $collector);

        return $taxon;
    }

    /**
     * @param Translation $translation
     * @param DataCollectorInterface $collector
     * @param string $fieldName
     * @param string $locale
     */
    private function mapTranslationField(Translation $translation, DataCollectorInterface $collector, $fieldName, $locale)
    {
        if ($collector->hasItem($fieldName, $locale)) {
            $method = 'set' . ucfirst(strtolower($fieldName));
            $translation->$method($collector->getItemValue($fieldName, $locale));
        }
    }

    /**
     * @param Taxon $taxon
     * @param DataCollectorInterface $collector
     */
    private function mapParentTaxon(Taxon $taxon, DataCollectorInterface $collector)
    {
        if (
            $collector->getItemValue('parentId') &&
            TaxonHandler::HANDLER_ID === $collector->getItemValue('parentClassName')
        ) {
            $taxon->setParent($collector->getItemValue('parentId'));
        }
    }
}
